# UpdateUserAuditTrailDto

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**user_id** | **str** |  | [optional] 
**entity_id** | **str** |  | [optional] 
**entity_type** | **str** |  | [optional] 
**entity_version** | **float** |  | [optional] 
**entity_diff** | **object** |  | [optional] 
**action** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

